I download and send audios of videos/tracks/sets/albums in MP3 128 kbps with tags and artwork. Files over 50 MB are split into parts due to bot-sent file size limit. Supported links:
*• SoundCloud*: tracks/playlists/pages with private widgets
*• Bandcamp*: tracks/albums/custom links
*• YouTube*: videos/playlists
*• Mixcloud, Vimeo and* [everything from this list](https://rg3.github.io/youtube-dl/supportedsites.html) (no VK music)

*Usage:*
• Send a message with links to the chat and I will download them instantly in private or ask you in groups. [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_ so I parse all group messages for links. Forwarded messages work too. For example:

`Check it out! https://m.soundcloud.com/richarddjames/umil-25-01 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix`

• Use `/dl <links>` to download instantly in groups.
• Use `/link <links>` to just get URL for downloading.
• Use `/clutter` to toggle replies to requests on or off.

*Credits // Emoji-links:*
[🌟 @GitHub](https://github.com/gpchelkin/scdlbot) // [⌨️⚠](https://github.com/gpchelkin/scdlbot/issues)
👨🏻‍💻 @gpchelkin // [🐝👍](http://xn--lo8h6c.ws/)
👩🏻‍🎨 @lowonbudget // [🎨🖼️](https://www.behance.net/lowonbudget)
🎶 @electrocircle // [⚡⚫](http://Электрокружок.РФ)
